bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 29. Aventiure
___________________________________________________ #### <Wie gen if vf stvont>
| ### o schieden sich die zwene reken lobelich ### Hagen von Trony vn– ovch her Dyterich ### do blikte vber ahsel ein Gvnthers man ### nach eime hergesellen den er vil schiere gewan
###### 1697 | ### Do sach er Volkern bi Gyselhere sten ### den spehen videlere er bat in mit im gen ### wan er vil wol erckande sinen grimmen mvot ### er waz an allen dingen ein ritter kvene vn– gvot
###### 1698 | ### Noch liezen si die herren vf dem hove stan ### niwan si zwene aleine sach man dannen gan ### vber den hof vil verre fvr einen palas wit ### die vz erwelten degne vorhten niemannes nit
###### 1699 | ### Si gesazen vor dern hvse gein eime sal ### der waz Kriemhilde vf eine banch zetal ### do lvht in vor dem libe ir herlich gewant ### genvoge die daz sahen heten gerne si bekant
###### 1700 | ### Alsam tier div wilden gekaphet wurden an ### die vbermveten helde von den Hvnen man ### si ersach dvrch ein venster ein Ecelen wip ### dez war aber betrvebet der schoenen Kriemhilde lip
###### 1701 | ### Ez mande si ir leide weinen si began ### des hete michel wunder die Ecelen man ### waz ir so rehte swere verrihtet hete ir mvot ### si sprach daz hat Hagne ir helde kvene <vnde> gvot
###### 1702 | ### Si sprachen zvo der vrowen wie ist daz geschehen ### wan wir ivch nivlich haben vro gesehen ### nie niemen wart so kvene derz iv hat getan ### heizet irz vns rechen ez sol im an sin leben gan
###### 1703 | ### Daz wold ich immer dienen swer reche miniv leit ### allez dez er gerte dez wer ich im bereit ### ich bivte michiv ze fvezen sprach des kvniges wip ### rechet mich an Hagnen daz er verlieze den lip
###### 1704 | ### Do garten sich vil balde sehcek kvener man ### dvrch Kriemhilde willen si wolden hin gan ### vn– wolden slahen Hagnen den vil kvenen man ### vn– ovch den videlere daz wart mit rate getan
###### 1705 | ### Do div kvniginne ir schar so kleine sach ### in eime grimmem mvote si ze den helden sprach ### dez ir da habet gedingen des svlt ir abe gan ### ia endvrfet ir so ringe Hagnen nimmer bestan
###### 1706 | ### Swie starc vn– swie kvene von Trony Hagne si ### noch ist verre stercher der im da sitzet bi [69b] ### Volker der videlere der ist ein vbel man ### ia ensvlt ir die helde niht so lihte bestan
###### 1707 | ### Do si daz gehorten do garte sich ir mere ### vierhvndert rechen div kvniginne her ### waz dez vil genoete daz si in tete læit ### da von wart sid den degnen <michel> sorge bereit
###### 1708 | ### Do si vil wol gewafent ir gesinde sach ### zvo den snellen reken div kvniginne sprach ### nv bitet ein wile ia svlt ir stille stan ### ich wil vnder krone zvo minen vinden gan
###### 1709 | ### Un– hoeret itewize waz mir hat getan ### Hagne von Trony Gvnthers man ### ich weiz in so vbermveten daz er mir lovgent niht ### so ist ovch mir vnmere swaz im darvmbe geschiht
###### 1710 | ### Do sach der videlere ein wundern kvene man ### die edeln kvniginne ab einer stiegen gan ### nider ab eime hvse do er daz ersach ### Volker der kvene zvo sime hergesellen sprach
###### 1711 | ### Nv schovwet vrivnt Hagne wa si dort here gat ### div vns an triwe inz lant geladet hat ### in gesach mit kvniges wibe nie so manigen man ### die swert enhende trvogen also stritlichen gan
###### 1712 | ### Wizzet ir vrivnt Hagne ob si iv sin gehaz ### so wil ich iv daz raten so hvetet deste baz ### des libes vn– der eren ia dvncket ez mich gvot ### als ich mich versinne si sint vil zornich gemvot
###### 1713 | ### Und sint ovch svmeliche cen brvsten also wit ### swer sin selbes hveten wil des ist wol zit ### ich wene si die liehten brvnne an in tragen ### wen si da mit mainen daz en hoer ich niemen sagen
###### 1714 | ### Do sprach in zornes mvote Hagne der chvene man ### ich weiz wol daz ez allez ist vf mich getan ### daz si div liehten wafen tragent an der hant ### vor den moeht ich geriten noh in der Bvrgonden lant
###### 1715 | ### Nv saget mir vrivnt Volker ob ir mir welt gestan ### ob mit mir wellent striten Kriemhilde man ### daz lazet ir mich hoern also liep als ich iv si ### ich won iv immer mere mit triwen dienstlichen bi
###### 1716 | ### Ich hilfe iv sicherlichen so sprach der spilman ### ob ich vns hie engegne sehe den kvnich gan ### mit allen sinen reken die wile ich leben mvoz ### so entwiche ich iv dvrh vorhte nimmer vz helfe einen fvoz
###### 1717 | ### Nv lon iv got von himele vil edel Volker ### ob si mit mir stritent wez bedarf ich danne mer ### sid ir mir helfen wellet als ich han vernomen ### so svln dise reken vil gewerlichen chomen
###### 1718 | ### Nv ste wir von dem sedele sprach der spilman ### si ist ein kvnigin vn– lat si fvr gan [70a] ### bieten ir die ere si ist ein edel wip ### damite ist ovch getiwert vnser ietweders lip
###### 1719 | ### Nein dvrch min liebe sprach do Hagne ### so wolden sich versinnen dise degne ### daz ichz dvrh vorhte tete vn– sold ich hin gen ### ich wil dvrch ir deheinen nimmer von dem sedel sten
###### 1720 | ### Ia zimet ez vns beiden zware lazzen baz ### zwiv sold ich den eren der mir ist gehaz ### daz getvon ich nimmer die wile ich han den lip ### ovch enrvoch ich waz mich nidet des kvnic Eceln wip
###### 1721 | ### Der vbermvete Hagne lette vber siniv bein ### ein vil liehtez wafen vz des knophe schein ### ein vil liehter iaspis grvener danne ein gras ### wol erkand ez Kriemhilt daz ez Sifrides waz
###### 1722 | ### Do si daz swert erchande do gie ir trvrens not ### daz gehilce was gvldin div scheide ein borte rot ### ez mande si ir læide weinen si began ### ich wene ez hete darvmbe der kvene Hagne getan
###### 1723 | ### Volker der snelle zoh naher vf der banch ### einen videlbogen starchen michel vnde lanch ### gelich eime swerte schærf vnde breit ### do sazen vneruohten die zwene reken gemeit
###### 1724 | ### Nv dvhten sich so here die zwene chvene man ### daz niht wolden von dem sedel stan ### dvrch niemens vorhte des gieng in an den fvoz ### div edel kvniginne vn– bot in ointlichen grvoz
###### 1725 | ### Si sprach nv saget her Hagne wer hat nah iv gesant ### daz ir getorstet riten her in ditz lant ### vn– ir daz wol erchandet waz ir mir habet getan ### hetet ir gvote sinne ir soldet ez billichen haben lan
###### 1726 | ### Nach mir ensande niemen sprach do Hagne ### man ladete her ze lande dri degne ### do heizent meine herren so bin ich ir man ### deheiner hovereise bin ich selden hinder in gestan
###### 1727 | ### Si sprach nv saget mir mer zwiv tatet ir daz ### daz ir habet verdient daz ich iv bin gehaz ### ir slvoget Sifriden minen lieben man ### dez ich vntz an min ende immer mer ze weinne han
###### 1728 | ### Er sprach waz sol des mer der rede ist nv genvoch ### ich binz et aber Hagne der Sifriden slvoch ### den helt ze sinen handen wie ser er des enkalt ### daz div vrowe Kriemhilt die schoenen Prvnhilde schalt
###### 1729 | ### Ez ist et ane lovgen kvniginne rich ### ich han des allez schvlde des schaden schedelich ### nv rech ez swer so welle ez si wip oder man ### ich enwold iv danne liegen ich han iv leides vil getvon
###### 1730 | ### Si sprach daz hoeret reken wa er mir lovgent niht ### aller miner leide swaz im da von geschiht ### daz ist mir vil vnmere ir Eceln man [70b] ### die vbermvoten degne sachen alle an ander an
###### 1731 | ### Swer den strit da hvebe so were da geschehen ### daz man den zwain gesellen der eren mvese iehen ### wan siz in stvrmen heten dike wol getan ### des sich iene vermazen dvrh vorhte mvosen si daz lan
###### 1732 | ### Do sprach der reken wes sehet ir mich an ### daz ich e da lobete des wil ich abe gan ### dvrch niemens gabe verliezen min lip ### ia wil vns verleiten des kvnich Eceln wip
###### 1733 | ### Do sprach da bi an ander des selben han ich mvot ### der mir gebe tvrne von rotem golde gvot ### disen videlere wol ich niht bestan ### dvrh sine swinde blike di ich an im gesehen han
###### 1734 | ### Och erchenne ich Hagnen von sinen ivngen tagen ### des mach man von dem reken lihte mir gesagen ### in zwein vn– zweincik stvrmen han ich in gesehen ### da vil maniger vrowen ist herzeleit von im geschehen
###### 1735 | ### Er vnd der von Spane traten manigen stic ### do si hie bi Ecele vahten manigen wic ### ze eren dem kvnige des ist vil geschehen ### darvmbe sol man Hagnen der eren billichen iehen
###### 1736 | ### Dannoch waz der reke siner iare ein chint ### daz do die tvmben warn wie grise die nv sintl ### nv ist er chomen ze witzen vn– ist ein grimmich man ### och treit er Balmungen daz er vbele gewan
###### 1737 | ### Da mite was gescheiden daz niemen da enstreit ### do wart der kvniginne vil hercenlichen læit ### die helde kerten danen ia vorhten si den tot ### von dem videlere des gie in sicherlichen not
###### 1738 | ### Do sprach der videlere wir han daz wol ersehen ### daz wir hie vinden vinde als wir e horten iehen ### wir svln zvo den kvnigin hintze hove gan ### so entar vnsere herren mit strite niemen wol bestan
###### 1739 | ### Wie dike ein man dvrh vorhte manigiv dinch verlat ### swa so vrivnt bi vrivnde gvetlichen stat ### vn– hat er gvete sinne daz er sin niht entvot ### schade vil maniges mannes wirt von sinnen wol behvot
###### 1740 | ### Nv wil ich iv nv volgen sprach do Hagne ### si giengen da si fvnden die ziern degne ### in grozem antvange an dem hove stan ### Volker der kvene vil lvte sprechen began
###### 1741 | ### zvo den sinen herren wie lange welt ir sten ### daz ir ivh lazet dringen ir svlt ze hove gen ### vn– hoeret an dem kvnige wie der si gemvot ### do sach man sich gesellen die helde kvene vn– gvot
###### 1742 | ### Der fvrste von Berne der nam an die hant ### Gvnthern den vil richen von Bvrgonden lant ### Irnvrit nam Gernoten den vil chvenen man ### do sach man Rvedegern ze hove mit Gyselhere gan [71a]
###### 1743 | ### Swie iemen sich gesellete vn– och ze hove gie ### Volker vn– Hagne geschieden sich nie ### niwan in eime stvrme vntz an ir endes zit ### daz mvozen edele vrowen beweinen grozlichen sit
###### 1744 | ### Do sach man mit den kvnigen ze hove gan ### ir edeln ingesindes tvsent kvener man ### dar vber sehzik rechen die worn mit in komen ### die hete in sime lande der kvene Hagne genomen
###### 1745 | ### Hawart vn– Irinc zwene vz erwelte man ### die sach man geselleclichen bi den kvnigen gan ### Dancwart vn– Wolfhart ein tiwerlicher degen ### die sach man wol ir tvgende vor den andern phlegen
###### 1746 | ### Do der voget von Rine in den palas gie ### Ecel der riche daz langer niht enlie ### er spranch von sime sedele als er in komen sach ### ein grvoz so rehte schoene von kvnige nie mer geschah
###### 1747 | ### Sit willekomen her Gvnther vn– och her Gernot ### vn– iwer brvoder Gyselher min dienst ich iv enbot ### mit triwen willeclichen ze Wormz vber Rin ### vn– allez daz gesinde daz sol mir willekomen sin
###### 1748 | ### Nv sit vns groze willechomen ir zwene degne ### Volker der vil kvene vnd ovch Hagne ### mir vn– miner vrowen her in ditze lant ### si hat iv boten manigen hin ze Rine gesant
###### 1749 | ### Do sprach von Trony Hagne des han ich vil vernomen ### wer ich dvrch min herren zen Hvnen niht enkomen ### so wer ich io ze ern geriten in daz lant ### do nam der wirt edel die lieben geste bi der hant
###### 1750 | ### Er brahte si ze dem sedele da er e selbe saz ### do schancte man den gesten mit vlize tet man daz ### in witen goldes schallen mete moraz vn– win ### vn– bat die ellenden groze willechomen sin
###### 1751 | ### Do sprach der chvnic Ecel des wil ich iv veriehen ### mir enchvnde in dirre werlde lieber niht gcschehen ### des ist der kvniginne vil michel trvrn benomen
###### 1752 | ### Mich nimet des immer wunder waz ich iv hab getan ### so manigen gast vil edele den ich gewunnen han ### daz ir nie gervohet komen in miniv lant ### daz ich ivch nv gesehen han daz ist ze vroeden mir gewant
###### 1753 | ### Dez antwurte Rvedeger ein riter hoch gemvot ### ir mvget si sehen gerne ir triwe div ist gvot ### miner vrowen mage der eren kvnnen phlegen ### si bringent iv ze hvse manigen wetlichen degen
###### 1754 | ### An svnewenden abent die herren warn komen ### in Eceln hof des richen vil seltem ist vernomen ### von also hohem grvoze als er die helde enphie ### nv waz och ezzens zit der kvnich mit in ze tische gie
###### 1755 | ### Ein wirt bi sinen gesten schoner nie gesaz [71b] ### man gab in volleclichen trinchen vnde maz ### allez des si gerten des waz man in bereit ### nan hete von den helden vil michel wunder geseit

<<< Übersicht <<< vorige Seite nächste Seite >>>